# NixOps configuration for deploying the Voices of Capricornia website
{
  self,
  config,
  inputs,
  pkgs,
  ...
}: let
  voc-web = import inputs.voc-web {};
  webdomain = "voicesofcapricornia.org";
in {
  environment.sessionVariables = {
    LOCALE_ARCHIVE = "/run/current-system/sw/lib/locale/locale-archive";
  };

  services.nginx = {
    enable = true; # Enable Nginx
    recommendedGzipSettings = true;
    recommendedOptimisation = true;
    recommendedProxySettings = true;
    recommendedTlsSettings = true;
    virtualHosts = {
      "${webdomain}" = {
        # website hostname
        enableACME = true; # Use ACME certs
        forceSSL = true; # Force SSL
        root = "${voc-web}"; # Wesbite root
      };
      "www.${webdomain}" = {
        # Respect our elders :-)
        locations."/".extraConfig = "return 301 $scheme://${webdomain}$request_uri;";
      };
    };
  };

  security.acme = {
    acceptTerms = true;
    certs = {
      "${webdomain}" = {
        email = "admin@${webdomain}";
        #group = "matrix-synapse";
      };
    };
  };

  networking.firewall.allowedTCPPorts = [80 443];
}
